See graph

Dependencies:   MCP23017 SDFileSystem WattBob_TextLCD mbed

Fork of Embedded_Software_Assignment_2 by Steven Kay

Revision:
3:c611b9bb5770
Parent:
2:22ebabd78084
Child:
4:b85bc0d810e1
--- a/main.cpp	Mon Feb 15 22:30:54 2016 +0000
+++ b/main.cpp	Wed Feb 17 10:22:50 2016 +0000
@@ -22,12 +22,19 @@
 
 DigitalOut myled(LED1);
 
-Task1 task1(p5); // Square wave Measurement
-
-Task3 task3(p6); // Watchdog Pulse
+Task1 task1(p5);                // Square wave Measurement
+Task2 task2_switch1(p6);        // Read digital Output
+Task3 task3(p7);                // Watchdog Pulse
+Task4 task4(p15,p16);           // Read analog Inputs
 
 
 int main() {
+    
+    task1.MeasureFreq();
+    int switch1State = task2_switch1.digitalInState();
+    task3.OutputWatchdogPulse();
+    float *analogReading = task4.returnAnalogReadings();
+    
     while(1) {
         myled = 1;
         wait(0.2);